@@ -56,6 +56,24 @@ from .plot_poly_resp import plot_polynomial_resp
 import threading
 
 def edit_xml_to_inv(args, scnl_filter):
+    """
+    Read in xml file(s), determine schema version, validate against schema version
+        Perform desired modifications (update/delete/add) to metadata
+        Return modified metadata in Inventory format
+
+    :param args: Determines what modifications to make to input metadata
+    :type args: class argparse.Namespace
+
+    :param scnl_filter: Filter that determines level (network, station, channel) at which to
+                        apply modifications
+    :type scnl_filter: Simple python struct for holding attributes
+
+    :returns: Modified metadata in obspy inventory format
+    :rtype: obspy.core.inventory.inventory
+
+    :returns: Schema_version
+    :rtype: string
+    """
 
     fname = 'edit_xml_to_inv'
 
@@ -158,7 +176,8 @@ def edit_xml_to_inv(args, scnl_filter):
         else:
             update_field(xml_list, scnl_filter, args)
     elif args.action == 'select':
-        filter_xml(xml_list, args.level, scnl_filter)
+        #filter_xml(xml_list, args.level, scnl_filter)
+        filter_xml(xml_list, scnl_filter)
 
     # Output the modified inventory/stationxml
     inv_new = pack_xml_list_to_inv(xml_list)
@@ -171,6 +190,14 @@ def edit_xml_to_inv(args, scnl_filter):
 import matplotlib.pyplot as plt
 
 def plot_responses(inventory, plot_dir):
+    """
+        Loop over channels in inventory, create response plot for each
+            channel and save to file in plot_dir
+        Response may be 'normal' (= use obspy response.plot()) or
+            polynomial (= use plot_polynomial_response() to generate fig)
+
+
+    """
     if plot_dir is None:
         plot_dir = "."
 
@@ -193,9 +220,12 @@ def plot_responses(inventory, plot_dir):
         for station in network.stations:
             for channel in station.channels:
                 sampling_rate = channel.sample_rate if channel.sample_rate > 0 else 100.
+
                 if channel.start_date is not None:
+                    start = channel.start_date.datetime.strftime('%Y-%m-%dT%H:%M:%S')
+                    end = channel.end_date.datetime.strftime('%Y-%m-%dT%H:%M:%S') if channel.end_date else None
                     label = "%s.%s.%s.%s.%s-%s" % (network.code, station.code, channel.code,
-                                                      channel.location_code, channel.start_date, channel.end_date)
+                                                      channel.location_code, start, end)
                 else:
                     label = "%s.%s.%s.%s" % (network.code, station.code, channel.code,
                                                    channel.location_code)
@@ -212,6 +242,7 @@ def plot_responses(inventory, plot_dir):
                                                axes=None, outfile=outfile)
 
                 else:
+                    print("MTH: label=%s" % label)
                     fig = channel.response.plot(min_freq, output="VEL", unwrap_phase=False,
                                                 sampling_rate=sampling_rate, label=label,
                                                 outfile=outfile)
@@ -221,7 +252,18 @@ def plot_responses(inventory, plot_dir):
 
     return
 
-def filter_xml(xml_list, level, scnl_filter):
+def filter_xml(xml_list, scnl_filter):
+    """
+    Filter (remove) elements defined in scnl_filter from xml_list
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :param scnl_filter: Filter that determines level (network, station, channel) at which to
+                        apply modifications
+    :type scnl_filter: Simple python struct for holding attributes
+
+    """
 
     if scnl_filter.NET:
         for xml_dict in xml_list:
@@ -252,6 +294,15 @@ def filter_xml(xml_list, level, scnl_filter):
 
 
 def update_root_field(xml_list, args):
+    """
+    Update a root field of FDSN StationXML within xml_list
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :param args: Determines what modifications to make to input metadata
+    :type args: class argparse.Namespace
+    """
     update_pair = args.update_pair
     field = update_pair[0]
     value = update_pair[1]
@@ -262,6 +313,20 @@ def update_root_field(xml_list, args):
     return
 
 def update_field(xml_list, scnl_filter, args):
+    """
+    Update a non-root field of FDSN StationXML within xml_list
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :param scnl_filter: Filter that determines level (network, station, channel) at which to
+                        apply modifications
+    :type scnl_filter: Simple python struct for holding attributes
+
+    :param args: Determines what modifications to make to input metadata
+    :type args: class argparse.Namespace
+    """
+    update_pair = args.update_pair
 
     level = args.level
 
@@ -363,6 +428,22 @@ def update_field(xml_list, scnl_filter, args):
 
 
 def add_base_node(xml_list, scnl_filter, level, obj):
+    """
+    Locate the appropriate position in xml_list and insert a new 
+        base node (Network, Station or Channel object).
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :param level: Level at which to apply changes, must be in {'network', 'station', 'channel'}
+    :type level: string
+
+    :param scnl_filter: simple python object holding NET, STA, CHA, LOC attributes that mods apply to
+    :type scnl_filter: python class used as container
+
+    :param obj: Obspy base_node object (Network, Station, Channel)
+    :type obj: obspy.core.inventory.network.Network, obspy.core.inventory.station.Station or obspy.core.inventory.channel.Channel
+    """
 
     if isinstance(obj, Network):
         logger.info("Add Network: Note that level is ignored since Network can only go in root")
@@ -415,6 +496,18 @@ def add_base_node(xml_list, scnl_filter, level, obj):
         logger.error("ERROR: Unknown combination: obj type:%s + level" % (type(obj)))
 
 def delete_base_node(xml_list, level, scnl_filter):
+    """
+    Find the base_node specified via level + scnl_filter and delete from xml_list
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :param level: Level at which to apply changes, must be in {'network', 'station', 'channel'}
+    :type level: string
+
+    :param scnl_filter: simple python object holding NET, STA, CHA, LOC attributes that mods apply to
+    :type scnl_filter: python class used as container
+    """
 
     if level == 'network':
         for xml_dict in xml_list:
@@ -482,6 +575,15 @@ def delete_base_node(xml_list, level, scnl_filter):
 
 
 def pack_xml_list_to_inv(xml_list):
+    """
+    Convert xml_list of dictionaries containing network(s) metadata to obspy inventory object
+
+    :param xml_list: List of python dicts containing metadata
+    :type xml_list: list
+
+    :returns: Inventory object created from xml_list
+    :rtype: obspy.core.inventory.inventory
+    """
 
     source = xml_list[0]['source']
     sender = xml_list[0]['sender']
@@ -505,6 +607,17 @@ def pack_xml_list_to_inv(xml_list):
     return inv
 
 def load_xmlfiles(xmlfiles):
+    """
+    Read list of xmlfile(s) into a list of python dicts, one for each xml file,
+          where the python dict holds the obspy inventory network objects
+          read from the file
+
+    :param xmlfiles: List of xmlfiles with common FDSN schema version
+    :type xmlfiles: list
+
+    :returns: list of python dicts
+    :rtype: list
+    """
 
     xml_list = []
 
@@ -546,6 +659,21 @@ def print_all(xml_list, args):
 
 
 def print_net(net_dict, args):
+    """
+    Checks a list of epochs for overlap
+        If overlap found, returns 1 + list of overlap messages
+        If overlap not found, returns 0 + empty list
+
+    :param epoch_list: List of any like objects with start_date + end_date,
+                       Pre-sorted by start_date
+    :type epoch_list: list
+
+    :returns: True/False if overlap found
+    :rtype: bool
+
+    :returns: List of overlap messages
+    :rtype: list
+    """
 
     for stn_code, stn_epochs in net_dict['sta_codes'].items():
 
@@ -582,6 +710,17 @@ def print_net(net_dict, args):
 
 
 def network_to_dict(network):
+    """
+    Convert obspy Network object to compound dict of sorted Station/Channel
+        objects (epochs).
+        Check for overlapping epochs at both Station + Channel level
+
+    :param network: Network
+    :type network: obspy.core.inventory.network.Network
+
+    :returns: Nested dict of sorted epochs
+    :rtype: dict
+    """
 
     net_dict = {}
     net_dict['sta_codes'] = {}
@@ -647,6 +786,22 @@ def network_to_dict(network):
 
 def overlapping_epochs(epoch_list):
 
+    """
+    Checks a list of epochs for overlap
+        If overlap found, returns 1 + list of overlap messages
+        If overlap not found, returns 0 + empty list
+
+    :param epoch_list: List of any like objects with start_date + end_date,
+                       Pre-sorted by start_date
+    :type epoch_list: list
+
+    :returns: 1 if overlap found else 0
+    :rtype: int
+
+    :returns: List of overlap messages
+    :rtype: list
+    """
+
     overlap = False
 
     msgs = []
